@@ -10,12 +10,8 @@ from libra_client import Client
 from libra.version import version
 import argparse
 import sys
-import os
 import signal
 
-sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), '../../')))
-sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), './')))
-
 
 TESTNET = NETWORKS['testnet']['host']
 
